@@ -10,7 +10,7 @@ from typing import List, Optional, Any, Dict, Sequence, Type
 from graphviz import Digraph
 from mixins import ReprMixin
 
-from datacode.graph.base import GraphObject
+from datacode.graph.base import GraphObject, Graphable
 from datacode.graph.edge import Edge
 from datacode.graph.node import Node
 from datacode.models.outputter import DataOutputter
@@ -23,7 +23,7 @@ from datacode.models.loader import DataLoader
 import datacode.hooks as hooks
 
 
-class DataSource(ReprMixin):
+class DataSource(Graphable, ReprMixin):
     copy_keys = [
         'location',
         'name',
@@ -124,10 +124,10 @@ class DataSource(ReprMixin):
         self.read_file_kwargs = read_file_kwargs
         self.data_outputter_kwargs = data_outputter_kwargs
         self.optimize_size = optimize_size
-        self.primary_node = Node(self.name)
         self._df = df
 
         self._validate()
+        super().__init__()
 
     def _validate(self):
         self._validate_load_variables()
@@ -381,6 +381,33 @@ class DataSource(ReprMixin):
             series = self.get_series_for(var=col.variable)
             col.series = series
 
+    def _wipe_columns_series(self):
+        cols_attrs = [
+            'columns',
+            '_orig_columns',
+            '_columns_for_calculate',
+        ]
+        for col_attr in cols_attrs:
+            cols = getattr(self, col_attr)
+            for col in cols:
+                col.series = None
+
+    def unlink_columns_and_variables(self):
+        self._wipe_columns_series()
+        copy_attrs = [
+            'columns',
+            'load_variables',
+            '_orig_columns',
+            '_columns_for_calculate',
+            '_orig_load_variables',
+            '_vars_for_calculate',
+        ]
+        for attr in copy_attrs:
+            orig_value = getattr(self, attr)
+            setattr(self, attr, deepcopy(orig_value))
+        if self._df is not None:
+            self.refresh_columns_series()
+
     def get_var_by_key(self, key: str, is_unique_key: bool = False) -> Variable:
         if is_unique_key:
             attr = 'unique_key'
@@ -521,22 +548,14 @@ class DataSource(ReprMixin):
 
         self.columns.append(col)
 
-    @property
-    def _graph_contents(self) -> Sequence[GraphObject]:
-        elems = [self.primary_node]
+    def _graph_contents(self, include_attrs: Optional[Sequence[str]] = None) -> List[GraphObject]:
+        pn = self.primary_node(include_attrs)
+        elems = [pn]
         if self.pipeline is not None:
-            elems.extend(self.pipeline._graph_contents)
-            elems.append(Edge(self.pipeline.primary_node, self.primary_node))
+            elems.extend(self.pipeline._graph_contents(include_attrs))
+            elems.append(Edge(self.pipeline.primary_node(include_attrs), pn))
         return elems
 
-    @property
-    def graph(self) -> Digraph:
-        elems = self._graph_contents
-        graph = Digraph(self.name)
-        for elem in elems:
-            elem.add_to_graph(graph)
-        return graph
-
 
 class NoColumnForVariableException(Exception):
     pass
